============================================
Rapport - Work report generator for the lazy
============================================

Writing work reports is tedious. Some people have custom hacks. This is meant to be the last one.


Features
--------

- Asyncronously collects data from various resources:
  - Bugzilla
  - Gerrit
  - Github
  - Launchpad
  - MediaWiki
  - OpenBuildService
  - Trello
  - Twitter
- Supports plugins for extendability
- Simple ini-style config file
- (Almost) comprehensive unit and functional testsuite
- Supports creating work reports for arbitrary timeframes and provides some convenient ones:
  - Current week / month
  - N last days (configurable)
  - N-th Week / month of year (configurable)

Written in Python, not VimScript, not Bash, not Ruby, not C, ..., you got it ;-)


Links
-----

- `Github <https://github.com/saschpe/rapport>`_
- `Python Package Index <https://pypi.python.org/pypi/rapport>`_
- `Open Build Service <https://build.opensuse.org/package/show?package=rapport&project=devel:languages:python>`_


License
-------

Currently licensed under GPL-2.0+


Author
------

Sascha Peilicke

